==> tryton-server_2.2.4.orig.tar.xz: trytond-2.2.4/trytond/ir/time_locale.py <==
# -*- coding: utf-8 -*-
#This file is part of Tryton.  The COPYRIGHT file at the top level of')
#this repository contains the full copyright notices and license terms.')
TIME_LOCALE = \
{'bg_BG': {'%A': [u'\u043f\u043e\u043d\u0435\u0434\u0435\u043b\u043d\u0438\u043a',
                  u'\u0432\u0442\u043e\u0440\u043d\u0438\u043a',
                  u'\u0441\u0440\u044f\u0434\u0430',
                  u'\u0447\u0435\u0442\u0432\u044a\u0440\u0442\u044a\u043a',
                  u'\u043f\u0435\u0442\u044a\u043a',
                  u'\u0441\u044a\u0431\u043e\u0442\u0430',
                  u'\u043d\u0435\u0434\u0435\u043b\u044f'],
           '%B': [None,
                  u'\u044f\u043d\u0443\u0430\u0440\u0438',
                  u'\u0444\u0435\u0432\u0440\u0443\u0430\u0440\u0438',
                  u'\u043c\u0430\u0440\u0442',
                  u'\u0430\u043f\u0440\u0438\u043b',
                  u'\u043c\u0430\u0439',
                  u'\u044e\u043d\u0438',
                  u'\u044e\u043b\u0438',
                  u'\u0430\u0432\u0433\u0443\u0441\u0442',
                  u'\u0441\u0435\u043f\u0442\u0435\u043c\u0432\u0440\u0438',
                  u'\u043e\u043a\u0442\u043e\u043c\u0432\u0440\u0438',
                  u'\u043d\u043e\u0435\u043c\u0432\u0440\u0438',
                  u'\u0434\u0435\u043a\u0435\u043c\u0432\u0440\u0438'],
           '%a': [u'\u043f\u043d',
                  u'\u0432\u0442',
                  u'\u0441\u0440',
                  u'\u0447\u0442',
                  u'\u043f\u0442',
                  u'\u0441\u0431',
                  u'\u043d\u0434'],
           '%b': [None,
                  u'\u044f\u043d\u0443',
                  u'\u0444\u0435\u0432',
                  u'\u043c\u0430\u0440',
                  u'\u0430\u043f\u0440',
                  u'\u043c\u0430\u0439',
                  u'\u044e\u043d\u0438',
                  u'\u044e\u043b\u0438',
                  u'\u0430\u0432\u0433',
                  u'\u0441\u0435\u043f',
                  u'\u043e\u043a\u0442',
                  u'\u043d\u043e\u0435',
                  u'\u0434\u0435\u043a'],
           '%p': [u'', u'']},
'cs_CZ': {'%A': [u'Pond\u011bl\xed',
                  u'\xdater\xfd',
                  u'St\u0159eda',
                  u'\u010ctvrtek',
                  u'P\xe1tek',
                  u'Sobota',
                  u'Ned\u011ble'],
           '%B': [None,
                  u'leden',
                  u'\xfanor',
                  u'b\u0159ezen',
                  u'duben',
                  u'kv\u011bten',
                  u'\u010derven',
                  u'\u010dervenec',
                  u'srpen',
                  u'z\xe1\u0159\xed',
                  u'\u0159\xedjen',
                  u'listopad',
                  u'prosinec'],
           '%a': [u'Po', u'\xdat', u'St', u'\u010ct', u'P\xe1', u'So', u'Ne'],
           '%b': [None,
                  u'led',
                  u'\xfano',
                  u'b\u0159e',
                  u'dub',
                  u'kv\u011b',
                  u'\u010den',
                  u'\u010dec',
                  u'srp',
                  u'z\xe1\u0159',
                  u'\u0159\xedj',
                  u'lis',
                  u'pro'],
           '%p': [u'', u'']},
 'de_DE': {'%A': [u'Montag',
                  u'Dienstag',
                  u'Mittwoch',
                  u'Donnerstag',
                  u'Freitag',
                  u'Samstag',
                  u'Sonntag'],
           '%B': [None,
                  u'Januar',
                  u'Februar',
                  u'M\xe4rz',
                  u'April',
                  u'Mai',
                  u'Juni',
                  u'Juli',
                  u'August',
                  u'September',
                  u'Oktober',
                  u'November',
                  u'Dezember'],
           '%a': [u'Mo', u'Di', u'Mi', u'Do', u'Fr', u'Sa', u'So'],
           '%b': [None,
                  u'Jan',
                  u'Feb',
                  u'M\xe4r',
                  u'Apr',
                  u'Mai',
                  u'Jun',
                  u'Jul',
                  u'Aug',
                  u'Sep',
                  u'Okt',
                  u'Nov',
                  u'Dez'],
           '%p': [u'', u'']},
 'en_US': {'%A': [u'Monday',
                  u'Tuesday',
                  u'Wednesday',
                  u'Thursday',
                  u'Friday',
                  u'Saturday',
                  u'Sunday'],
           '%B': [None,
                  u'January',
                  u'February',
                  u'March',
                  u'April',
                  u'May',
                  u'June',
                  u'July',
                  u'August',
                  u'September',
                  u'October',
                  u'November',
                  u'December'],
           '%a': [u'Mon', u'Tue', u'Wed', u'Thu', u'Fri', u'Sat', u'Sun'],
           '%b': [None,
                  u'Jan',
                  u'Feb',
                  u'Mar',
                  u'Apr',
                  u'May',
                  u'Jun',
                  u'Jul',
                  u'Aug',
                  u'Sep',
                  u'Oct',
                  u'Nov',
                  u'Dec'],
           '%p': [u'AM', u'PM']},
 'es_CO': {'%A': [u'lunes',
                  u'martes',
                  u'mi\xe9rcoles',
                  u'jueves',
                  u'viernes',
                  u's\xe1bado',
                  u'domingo'],
           '%B': [None,
                  u'enero',
                  u'febrero',
                  u'marzo',
                  u'abril',
                  u'mayo',
                  u'junio',
                  u'julio',
                  u'agosto',
                  u'septiembre',
                  u'octubre',
                  u'noviembre',
                  u'diciembre'],
           '%a': [u'lun',
                  u'mar',
                  u'mi\xe9',
                  u'jue',
                  u'vie',
                  u's\xe1b',
                  u'dom'],
           '%b': [None,
                  u'ene',
                  u'feb',
                  u'mar',
                  u'abr',
                  u'may',
                  u'jun',
                  u'jul',
                  u'ago',
                  u'sep',
                  u'oct',
                  u'nov',
                  u'dic'],
           '%p': [u'', u'']},
 'es_ES': {'%A': [u'lunes',
                  u'martes',
                  u'mi\xe9rcoles',
                  u'jueves',
                  u'viernes',
                  u's\xe1bado',
                  u'domingo'],
           '%B': [None,
                  u'enero',
                  u'febrero',
                  u'marzo',
                  u'abril',
                  u'mayo',
                  u'junio',
                  u'julio',
                  u'agosto',
                  u'septiembre',
                  u'octubre',
                  u'noviembre',
                  u'diciembre'],
           '%a': [u'lun',
                  u'mar',
                  u'mi\xe9',
                  u'jue',
                  u'vie',
                  u's\xe1b',
                  u'dom'],
           '%b': [None,
                  u'ene',
                  u'feb',
                  u'mar',
                  u'abr',
                  u'may',
                  u'jun',
                  u'jul',
                  u'ago',
                  u'sep',
                  u'oct',
                  u'nov',
                  u'dic'],
           '%p': [u'', u'']},
 'fr_FR': {'%A': [u'lundi',
                  u'mardi',
                  u'mercredi',
                  u'jeudi',
                  u'vendredi',
                  u'samedi',
                  u'dimanche'],
           '%B': [None,
                  u'janvier',
                  u'f\xe9vrier',
                  u'mars',
                  u'avril',
                  u'mai',
                  u'juin',
                  u'juillet',
                  u'ao\xfbt',
                  u'septembre',
                  u'octobre',
                  u'novembre',
                  u'd\xe9cembre'],
           '%a': [u'lun.',
                  u'mar.',
                  u'mer.',
                  u'jeu.',
                  u'ven.',
                  u'sam.',
                  u'dim.'],
           '%b': [None,
                  u'janv.',
                  u'f\xe9vr.',
                  u'mars',
                  u'avril',
                  u'mai',
                  u'juin',
                  u'juil.',
                  u'ao\xfbt',
                  u'sept.',
                  u'oct.',
                  u'nov.',
                  u'd\xe9c.'],
           '%p': [u'', u'']}}

==> tryton-server_3.0.2.orig.tar.xz: trytond-3.0.2/trytond/ir/time_locale.py <==
# -*- coding: utf-8 -*-
#This file is part of Tryton.  The COPYRIGHT file at the top level of')
#this repository contains the full copyright notices and license terms.')
TIME_LOCALE = \
{'bg_BG': {'%A': [u'\u043f\u043e\u043d\u0435\u0434\u0435\u043b\u043d\u0438\u043a',
                  u'\u0432\u0442\u043e\u0440\u043d\u0438\u043a',
                  u'\u0441\u0440\u044f\u0434\u0430',
                  u'\u0447\u0435\u0442\u0432\u044a\u0440\u0442\u044a\u043a',
                  u'\u043f\u0435\u0442\u044a\u043a',
                  u'\u0441\u044a\u0431\u043e\u0442\u0430',
                  u'\u043d\u0435\u0434\u0435\u043b\u044f'],
           '%B': [None,
                  u'\u044f\u043d\u0443\u0430\u0440\u0438',
                  u'\u0444\u0435\u0432\u0440\u0443\u0430\u0440\u0438',
                  u'\u043c\u0430\u0440\u0442',
                  u'\u0430\u043f\u0440\u0438\u043b',
                  u'\u043c\u0430\u0439',
                  u'\u044e\u043d\u0438',
                  u'\u044e\u043b\u0438',
                  u'\u0430\u0432\u0433\u0443\u0441\u0442',
                  u'\u0441\u0435\u043f\u0442\u0435\u043c\u0432\u0440\u0438',
                  u'\u043e\u043a\u0442\u043e\u043c\u0432\u0440\u0438',
                  u'\u043d\u043e\u0435\u043c\u0432\u0440\u0438',
                  u'\u0434\u0435\u043a\u0435\u043c\u0432\u0440\u0438'],
           '%a': [u'\u043f\u043d',
                  u'\u0432\u0442',
                  u'\u0441\u0440',
                  u'\u0447\u0442',
                  u'\u043f\u0442',
                  u'\u0441\u0431',
                  u'\u043d\u0434'],
           '%b': [None,
                  u'\u044f\u043d\u0443',
                  u'\u0444\u0435\u0432',
                  u'\u043c\u0430\u0440',
                  u'\u0430\u043f\u0440',
                  u'\u043c\u0430\u0439',
                  u'\u044e\u043d\u0438',
                  u'\u044e\u043b\u0438',
                  u'\u0430\u0432\u0433',
                  u'\u0441\u0435\u043f',
                  u'\u043e\u043a\u0442',
                  u'\u043d\u043e\u0435',
                  u'\u0434\u0435\u043a'],
           '%p': [u'', u'']},
 'ca_ES': {'%A': [u'dilluns',
                  u'dimarts',
                  u'dimecres',
                  u'dijous',
                  u'divendres',
                  u'dissabte',
                  u'diumenge'],
           '%B': [None,
                  u'gener',
                  u'febrer',
                  u'mar\xe7',
                  u'abril',
                  u'maig',
                  u'juny',
                  u'juliol',
                  u'agost',
                  u'setembre',
                  u'octubre',
                  u'novembre',
                  u'desembre'],
           '%a': [u'dl', u'dt', u'dc', u'dj', u'dv', u'ds', u'dg'],
           '%b': [None,
                  u'gen',
                  u'feb',
                  u'mar',
                  u'abr',
                  u'mai',
                  u'jun',
                  u'jul',
                  u'ago',
                  u'set',
                  u'oct',
                  u'nov',
                  u'des'],
           '%p': [u'', u'']},
 'cs_CZ': {'%A': [u'Pond\u011bl\xed',
                  u'\xdater\xfd',
                  u'St\u0159eda',
                  u'\u010ctvrtek',
                  u'P\xe1tek',
                  u'Sobota',
                  u'Ned\u011ble'],
           '%B': [None,
                  u'leden',
                  u'\xfanor',
                  u'b\u0159ezen',
                  u'duben',
                  u'kv\u011bten',
                  u'\u010derven',
                  u'\u010dervenec',
                  u'srpen',
                  u'z\xe1\u0159\xed',
                  u'\u0159\xedjen',
                  u'listopad',
                  u'prosinec'],
           '%a': [u'Po', u'\xdat', u'St', u'\u010ct', u'P\xe1', u'So', u'Ne'],
           '%b': [None,
                  u'led',
                  u'\xfano',
                  u'b\u0159e',
                  u'dub',
                  u'kv\u011b',
                  u'\u010den',
                  u'\u010dec',
                  u'srp',
                  u'z\xe1\u0159',
                  u'\u0159\xedj',
                  u'lis',
                  u'pro'],
           '%p': [u'', u'']},
 'de_DE': {'%A': [u'Montag',
                  u'Dienstag',
                  u'Mittwoch',
                  u'Donnerstag',
                  u'Freitag',
                  u'Samstag',
                  u'Sonntag'],
           '%B': [None,
                  u'Januar',
                  u'Februar',
                  u'M\xe4rz',
                  u'April',
                  u'Mai',
                  u'Juni',
                  u'Juli',
                  u'August',
                  u'September',
                  u'Oktober',
                  u'November',
                  u'Dezember'],
           '%a': [u'Mo', u'Di', u'Mi', u'Do', u'Fr', u'Sa', u'So'],
           '%b': [None,
                  u'Jan',
                  u'Feb',
                  u'M\xe4r',
                  u'Apr',
                  u'Mai',
                  u'Jun',
                  u'Jul',
                  u'Aug',
                  u'Sep',
                  u'Okt',
                  u'Nov',
                  u'Dez'],
           '%p': [u'', u'']},
 'en_US': {'%A': [u'Monday',
                  u'Tuesday',
                  u'Wednesday',
                  u'Thursday',
                  u'Friday',
                  u'Saturday',
                  u'Sunday'],
           '%B': [None,
                  u'January',
                  u'February',
                  u'March',
                  u'April',
                  u'May',
                  u'June',
                  u'July',
                  u'August',
                  u'September',
                  u'October',
                  u'November',
                  u'December'],
           '%a': [u'Mon', u'Tue', u'Wed', u'Thu', u'Fri', u'Sat', u'Sun'],
           '%b': [None,
                  u'Jan',
                  u'Feb',
                  u'Mar',
                  u'Apr',
                  u'May',
                  u'Jun',
                  u'Jul',
                  u'Aug',
                  u'Sep',
                  u'Oct',
                  u'Nov',
                  u'Dec'],
           '%p': [u'AM', u'PM']},
 'es_AR': {'%A': [u'lunes',
                  u'martes',
                  u'mi\xe9rcoles',
                  u'jueves',
                  u'viernes',
                  u's\xe1bado',
                  u'domingo'],
           '%B': [None,
                  u'enero',
                  u'febrero',
                  u'marzo',
                  u'abril',
                  u'mayo',
                  u'junio',
                  u'julio',
                  u'agosto',
                  u'septiembre',
                  u'octubre',
                  u'noviembre',
                  u'diciembre'],
           '%a': [u'lun',
                  u'mar',
                  u'mi\xe9',
                  u'jue',
                  u'vie',
                  u's\xe1b',
                  u'dom'],
           '%b': [None,
                  u'ene',
                  u'feb',
                  u'mar',
                  u'abr',
                  u'may',
                  u'jun',
                  u'jul',
                  u'ago',
                  u'sep',
                  u'oct',
                  u'nov',
                  u'dic'],
           '%p': [u'', u'']},
 'es_CO': {'%A': [u'lunes',
                  u'martes',
                  u'mi\xe9rcoles',
                  u'jueves',
                  u'viernes',
                  u's\xe1bado',
                  u'domingo'],
           '%B': [None,
                  u'enero',
                  u'febrero',
                  u'marzo',
                  u'abril',
                  u'mayo',
                  u'junio',
                  u'julio',
                  u'agosto',
                  u'septiembre',
                  u'octubre',
                  u'noviembre',
                  u'diciembre'],
           '%a': [u'lun',
                  u'mar',
                  u'mi\xe9',
                  u'jue',
                  u'vie',
                  u's\xe1b',
                  u'dom'],
           '%b': [None,
                  u'ene',
                  u'feb',
                  u'mar',
                  u'abr',
                  u'may',
                  u'jun',
                  u'jul',
                  u'ago',
                  u'sep',
                  u'oct',
                  u'nov',
                  u'dic'],
           '%p': [u'AM', u'PM']},
 'es_ES': {'%A': [u'lunes',
                  u'martes',
                  u'mi\xe9rcoles',
                  u'jueves',
                  u'viernes',
                  u's\xe1bado',
                  u'domingo'],
           '%B': [None,
                  u'enero',
                  u'febrero',
                  u'marzo',
                  u'abril',
                  u'mayo',
                  u'junio',
                  u'julio',
                  u'agosto',
                  u'septiembre',
                  u'octubre',
                  u'noviembre',
                  u'diciembre'],
           '%a': [u'lun',
                  u'mar',
                  u'mi\xe9',
                  u'jue',
                  u'vie',
                  u's\xe1b',
                  u'dom'],
           '%b': [None,
                  u'ene',
                  u'feb',
                  u'mar',
                  u'abr',
                  u'may',
                  u'jun',
                  u'jul',
                  u'ago',
                  u'sep',
                  u'oct',
                  u'nov',
                  u'dic'],
           '%p': [u'', u'']},
 'fr_FR': {'%A': [u'lundi',
                  u'mardi',
                  u'mercredi',
                  u'jeudi',
                  u'vendredi',
                  u'samedi',
                  u'dimanche'],
           '%B': [None,
                  u'janvier',
                  u'f\xe9vrier',
                  u'mars',
                  u'avril',
                  u'mai',
                  u'juin',
                  u'juillet',
                  u'ao\xfbt',
                  u'septembre',
                  u'octobre',
                  u'novembre',
                  u'd\xe9cembre'],
           '%a': [u'lun.',
                  u'mar.',
                  u'mer.',
                  u'jeu.',
                  u'ven.',
                  u'sam.',
                  u'dim.'],
           '%b': [None,
                  u'janv.',
                  u'f\xe9vr.',
                  u'mars',
                  u'avril',
                  u'mai',
                  u'juin',
                  u'juil.',
                  u'ao\xfbt',
                  u'sept.',
                  u'oct.',
                  u'nov.',
                  u'd\xe9c.'],
           '%p': [u'', u'']},
 'nl_NL': {'%A': [u'maandag',
                  u'dinsdag',
                  u'woensdag',
                  u'donderdag',
                  u'vrijdag',
                  u'zaterdag',
                  u'zondag'],
           '%B': [None,
                  u'januari',
                  u'februari',
                  u'maart',
                  u'april',
                  u'mei',
                  u'juni',
                  u'juli',
                  u'augustus',
                  u'september',
                  u'oktober',
                  u'november',
                  u'december'],
           '%a': [u'ma', u'di', u'wo', u'do', u'vr', u'za', u'zo'],
           '%b': [None,
                  u'jan',
                  u'feb',
                  u'mrt',
                  u'apr',
                  u'mei',
                  u'jun',
                  u'jul',
                  u'aug',
                  u'sep',
                  u'okt',
                  u'nov',
                  u'dec'],
           '%p': [u'', u'']},
 'ru_RU': {'%A': [u'\u041f\u043e\u043d\u0435\u0434\u0435\u043b\u044c\u043d\u0438\u043a',
                  u'\u0412\u0442\u043e\u0440\u043d\u0438\u043a',
                  u'\u0421\u0440\u0435\u0434\u0430',
                  u'\u0427\u0435\u0442\u0432\u0435\u0440\u0433',
                  u'\u041f\u044f\u0442\u043d\u0438\u0446\u0430',
                  u'\u0421\u0443\u0431\u0431\u043e\u0442\u0430',
                  u'\u0412\u043e\u0441\u043a\u0440\u0435\u0441\u0435\u043d\u044c\u0435'],
           '%B': [None,
                  u'\u042f\u043d\u0432\u0430\u0440\u044c',
                  u'\u0424\u0435\u0432\u0440\u0430\u043b\u044c',
                  u'\u041c\u0430\u0440\u0442',
                  u'\u0410\u043f\u0440\u0435\u043b\u044c',
                  u'\u041c\u0430\u0439',
                  u'\u0418\u044e\u043d\u044c',
                  u'\u0418\u044e\u043b\u044c',
                  u'\u0410\u0432\u0433\u0443\u0441\u0442',
                  u'\u0421\u0435\u043d\u0442\u044f\u0431\u0440\u044c',
                  u'\u041e\u043a\u0442\u044f\u0431\u0440\u044c',
                  u'\u041d\u043e\u044f\u0431\u0440\u044c',
                  u'\u0414\u0435\u043a\u0430\u0431\u0440\u044c'],
           '%a': [u'\u041f\u043d.',
                  u'\u0412\u0442.',
                  u'\u0421\u0440.',
                  u'\u0427\u0442.',
                  u'\u041f\u0442.',
                  u'\u0421\u0431.',
                  u'\u0412\u0441.'],
           '%b': [None,
                  u'\u044f\u043d\u0432.',
                  u'\u0444\u0435\u0432\u0440.',
                  u'\u043c\u0430\u0440\u0442\u0430',
                  u'\u0430\u043f\u0440.',
                  u'\u043c\u0430\u044f',
                  u'\u0438\u044e\u043d\u044f',
                  u'\u0438\u044e\u043b\u044f',
                  u'\u0430\u0432\u0433.',
                  u'\u0441\u0435\u043d\u0442.',
                  u'\u043e\u043a\u0442.',
                  u'\u043d\u043e\u044f\u0431.',
                  u'\u0434\u0435\u043a.'],
           '%p': [u'', u'']},
  'sl_SI': {'%A':  [u'ponedeljek',
                    u'torek',
                    u'sreda',
                    u'\u010detrtek',
                    u'petek',
                    u'sobota',
                    u'nedelja'],
             '%B': [None,
                    u'januar',
                    u'februar',
                    u'marec',
                    u'april',
                    u'maj',
                    u'junij',
                    u'julij',
                    u'avgust',
                    u'september',
                    u'oktober',
                    u'november',
                    u'december'],
             '%a': [u'pon', u'tor', u'sre', u'\u010det', u'pet', u'sob', u'ned'],
             '%b': [None,
                    u'jan',
                    u'feb',
                    u'mar',
                    u'apr',
                    u'maj',
                    u'jun',
                    u'jul',
                    u'avg',
                    u'sep',
                    u'okt',
                    u'nov',
                    u'dec'],
             '%p': [u'', u'']}}
